pub async fn execute_prepared<C: GenericClient + Sync>(
client: &C,
statement: &Statement,
params: &[&(dyn ToSql + Sync)],
) -> Result<u64, PostgresError>Expand description
Runs a prepared query and returns the number of affected rows.
pub async fn execute_prepared<C: GenericClient + Sync>(
client: &C,
statement: &Statement,
params: &[&(dyn ToSql + Sync)],
) -> Result<u64, PostgresError>Runs a prepared query and returns the number of affected rows.